@echo OFF
rem  * *******************************************************************
rem  *               CBLVLRE1.cmd - a Windows Command File               *
rem  *         This program is provided by SimoTime Technologies         *
rem  *           (C) Copyright 1987-2019 All Rights Reserved             *
rem  *             Web Site URL:   http://www.simotime.com               *
rem  *                   e-mail:   helpdesk@simotime.com                 *
rem  * *******************************************************************
rem  *
rem  * Text    - Data File Conversion, Variable Length Records
rem  * Author  - SimoTime Technologies
rem  * Date    - May 04, 2004
rem  * Version - 04.03.12
rem  *
rem  * This set of programs illustrate how to port a file with variable
rem  * length records to a Micro Focus platform using Net Express.
rem  *
rem  * When running with Net Express the IBMCOMP an NOTRUNC directives
rem  * will be required to maintain compatability with the mainframe
rem  * format and field sizes for binary fields.
rem  *
rem  * This set of programs will run on a Personal Computer with Windows
rem  * and Micro Focus Net Express.
rem  *
rem  * With two eceptions the files are processed using the standard COBOL
rem  * coding techniques with the SELECT and FD statements. The two
rem  * exceptions are the mainframe image files (FTEDBV01 and FTEDBV02)
rem  * files that are variable length records. These files are processed
rem  * using the Micro Focus Byte-Stream-Input-Output (BSIO) access method.
rem  * The mainframe image files may also be downloaded from the mainframe
rem  * using FTP and MODE BINARY.
rem  *
rem  * ********************************************************************
rem  * Step 1 of 10, Set the common environment variables...
rem  *
     if "%SYSLOG%" == "" set syslog=c:\SimoLIBR\LOGS\SimoTime.LOG
     set CmdName=CblVlrE1
     call ..\Env1BASE
rem  *
     call SimoNOTE "**********************************************************************%CmdName%"
     call SimoNOTE "Starting CmdName  %CmdName%"
rem  * ********************************************************************
rem  * Step 2 of 10, Create the ALPHA Files...
rem  *
     call SimoNOTE "Identify JobStep  Create the Alpha Files"
     call CrtAlfE1 nopause
rem  * ********************************************************************
rem  * Step 3 of 10, Read RSEQ, EBCDIC, 80 and write ZOS Variable 4-32760
rem  *
     call SimoNOTE "*--------------------------------------------------------------------*"
     call SimoNOTE "Annotate Read RSEQ, EBCDIC, Fixed-80 and write ZOS Variable 4-32760"
     set ALPHARSE=%BaseLib1%\DATA\Wrk1\SIMOTIME.DATA.ALPHARSE.DAT
     set BSIODSN1=%BaseLib1%\DATA\Wrk1\SIMOTIME.DATA.ALPHAZ01.ZOS
     set BSIOFMT1=V
     run CblVlrC2
     if ERRORLEVEL = 1 set JobStatus=0030
     if not "%JobStatus%" == "0000" goto :EojNOK
     call SimoNOTE "DataTake ALPHARSE=%ALPHARSE%"
     call SimoNOTE "DataMake BSIODSN1=%BSIODSN1%"
rem  * ********************************************************************
rem  * Step   4 of 10  Read ZOS Variable and write MF Variable...
rem  *
     call SimoNOTE "*--------------------------------------------------------------------*"
     call SimoNOTE "Annotate Read ZOS Variable 4-32760 and write MF Variable 4-32760"
     set BSIODSN1=%BaseLib1%\DATA\Wrk1\SIMOTIME.DATA.ALPHAZ01.ZOS
     set ALPHAV01=%BaseLib1%\DATA\Wrk1\SIMOTIME.DATA.ALPHAV01.DAT
     run CblVlrC3
     if ERRORLEVEL = 1 set JobStatus=0040
     if not "%JobStatus%" == "0000" goto :EojNOK
     call SimoNOTE "DataTake BSIODSN1=%BSIODSN1%"
     call SimoNOTE "DataMake ALPHAV01=%ALPHAV01%"
rem  * ********************************************************************
rem  * Step   5 of 10  Read MF Variable and write ZOS Variable...
rem  *
     call SimoNOTE "*--------------------------------------------------------------------*"
     call SimoNOTE "Annotate Read MF Variable 4-32760 and write ZOS Variable 4-32760"
     set ALPHAV01=%BaseLib1%\DATA\Wrk1\SIMOTIME.DATA.ALPHAV01.DAT
     set BSIODSN2=%BaseLib1%\DATA\Wrk1\SIMOTIME.DATA.ALPHAZ02.ZOS
     set BSIOFMT1=V
     run CblVlrC4
     if ERRORLEVEL = 1 set JobStatus=0050
     if not "%JobStatus%" == "0000" goto :EojNOK
     call SimoNOTE "DataTake ALPHAV01=%ALPHAV01%"
     call SimoNOTE "DataMake BSIODSN2=%BSIODSN2%"
rem  * ********************************************************************
rem  * Step   6 of 10  Read ZOS Variable and write SEQUENTIAL Fixed...
rem  *
     call SimoNOTE "*--------------------------------------------------------------------*"
     call SimoNOTE "Annotate Read ZOS Variable 4-32760 and write RSEQ EBCDIC Fixed-80"
     set BSIODSN2=%BaseLib1%\DATA\Wrk1\SIMOTIME.DATA.ALPHAZ02.ZOS
     set ALPHARS2=%BaseLib1%\DATA\Wrk1\SIMOTIME.DATA.ALPHARS2.DAT
     run CblVlrC5
     if ERRORLEVEL = 1 set JobStatus=0060
     if not "%JobStatus%" == "0000" goto :EojNOK
     call SimoNOTE "DataTake BSIODSN2=%BSIODSN2%"
     call SimoNOTE "DataMake ALPHARS2=%ALPHARS2%"
rem  * ********************************************************************
rem  * Step   7 of 10  Read SEQUENTIAL-FIXED and write ASCII/Text...
rem  *
     call SimoNOTE "*--------------------------------------------------------------------*"
     call SimoNOTE "Annotate Read RSEQ EBCDIC Fixed-80 and write LSEQ ASCII Variable"
     set ALPHARS2=%BaseLib1%\DATA\Wrk1\SIMOTIME.DATA.ALPHARS2.DAT
     set ALPHALS2=%BaseLib1%\DATA\Wrk1\SIMOTIME.DATA.ALPHALS2.TXT
     run CblVlrC6
     if ERRORLEVEL = 1 set JobStatus=0070
     if not "%JobStatus%" == "0000" goto :EojNOK
     call SimoNOTE "DataTake ALPHARS2=%ALPHARS2%"
     call SimoNOTE "DataMake ALPHALS2=%ALPHALS2%"
rem  * ********************************************************************
rem  * Step   8  of 10  Compare ASCII/Text Files...
rem  *
     call SimoNOTE "*--------------------------------------------------------------------*"
     call SimoNOTE "Annotate Compare ASCII/Text Files..."
     set LS80UT01=%BaseLib1%\DATA\Wrk1\SIMOTIME.DATA.ALPHALS1.TXT
     set LS80UT02=%BaseLib1%\DATA\Wrk1\SIMOTIME.DATA.ALPHALS2.TXT
     run CBLVLRC1
     if ERRORLEVEL = 1 set JobStatus=0080
     if not "%JobStatus%" == "0000" goto :EojNOK
     call SimoNOTE "DataTake LS80UT01=%LS80UT01%"
     call SimoNOTE "DataTake LS80UT02=%LS80UT02%"
rem  * ********************************************************************
rem  * Step   9 of 10  Read MF-VARABLE-EBCDIC and write ASCII/Text...
rem  *
     call SimoNOTE "*--------------------------------------------------------------------*"
     call SimoNOTE "Annotate Read RSEQ EBCDIC Variable 4-32760, write LSEQ ASCII Variable"
     set ALPHAV01=%BaseLib1%\DATA\Wrk1\SIMOTIME.DATA.ALPHAV01.DAT
     set ALPHALS3=%BaseLib1%\DATA\Wrk1\SIMOTIME.DATA.ALPHALS3.TXT
     run CblVlrC7
     if ERRORLEVEL = 1 set JobStatus=0090
     if not "%JobStatus%" == "0000" goto :EojNOK
     call SimoNOTE "DataTake ALPHAV01=%ALPHAV01%"
     call SimoNOTE "DataMake ALPHALS3=%ALPHALS3%"
rem  * ********************************************************************
rem  * Step   10 of 10  Compare ASCII/Text Files...
rem  *
     call SimoNOTE "*--------------------------------------------------------------------*"
     call SimoNOTE "Annotate Compare ASCII/Text Files..."
     set LS80UT01=%BaseLib1%\DATA\Wrk1\SIMOTIME.DATA.ALPHALS1.TXT
     set LS80UT02=%BaseLib1%\DATA\Wrk1\SIMOTIME.DATA.ALPHALS3.TXT
     run CBLVLRC1
     if ERRORLEVEL = 1 set JobStatus=0100
     if not "%JobStatus%" == "0000" goto :EojNOK
     call SimoNOTE "DataTake LS80UT01=%LS80UT01%"
     call SimoNOTE "DataTake LS80UT02=%LS80UT02%"
:EojAOK
     call SimoNOTE "*--------------------------------------------------------------------*"
     call SimoNOTE "Finished CmdName  %CmdName%, Job Status is %JobStatus%"
     goto :End
:EojNOK
     call SimoNOTE "*--------------------------------------------------------------------*"
     call SimoNOTE "ABENDING CmdName  %CmdName%, Job Status is %JobStatus%"
     goto :End
:End
     call SimoNOTE "Conclude SysLog is %SYSLOG%"
     if not "%1" == "nopause" pause
